#! /usr/local/bin/RScript
# March 14, 2018
# A take on test2.sptree part of phybase
# requires you to
# set the number of bootstraps (nbootstrap<-10)
# have the three trees to compare pointed to, mine are CT.tre, CS.tre, ST.tre
# I used a vector of species names, speciesV
# you have to give mpest rooted trees, somehow, "midpointGeneTrees.trees"
#setwd("~/Dropbox/salmoUCEs/mp-est/100/")
library("phybase")
nbootstrap<-100

#####
sp1<-read.tree.string("CT.tre")
sp2<-read.tree.string("CS.tre")
sp3<-read.tree.string("ST.tre")

speciesV<-c("Coregonus_laurettae55_57","Coregonus_sardinella41_71","Coregonus_pidschian36_73",
            "Stenodus_leucichthys51_57","Prosopium_cylindraceum53_59","Thymallus_grubii10_77",
            "Thymallus_arcticus57_59","Parahucho_perryi15_73","Brachymystax_lenok32_79",
            "Salvelinus_alpinus9_75","Oncorhynchus_mykiss20_73","salvelinus_fontinalis",
            "Oncorhynchus_tshawytscha16_73","Salmo_salar13_75","Hucho_taimen31_75",
            "umbra_limi","Esox_lucius3_61")

geneTrees<-read.tree("midpointGeneTrees.trees")
#geneTrees<-read.tree("rootedGeneTrees.trees")
ngenetree<-length(geneTrees)

#working command
#tree1_mpest<-run.mpest(path_mpest = "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", genetreefile = "midpointGeneTrees.trees",     species=as.vector(species.name(sp1)), ntree=6)

tree1_mpest<-run.mpest(path_mpest = "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", genetreefile = "midpointGeneTrees.trees", 
                      species=speciesV, sptree=sp1$tree, ntree=ngenetree)

tree2_mpest<-run.mpest(path_mpest = "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", genetreefile = "midpointGeneTrees.trees", 
                       species=speciesV, sptree=sp2$tree, ntree=ngenetree)

tree3_mpest<-run.mpest(path_mpest = "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", genetreefile = "midpointGeneTrees.trees", 
                      species=speciesV, sptree=sp3$tree, ntree=ngenetree)

###Compare trees 1 & 2####
if(tree1_mpest$loglike > tree2_mpest$loglike){
  teststat = 2*(tree1_mpest$loglike - tree2_mpest$loglike)
  nulltree = tree2_mpest$tree
}else{
  teststat = 2*(tree2_mpest$loglike - tree1_mpest$loglike)
  nulltree = tree1_mpest$tree
}


tree1_loglike=tree2_loglike=1:nbootstrap

for(i in 1:nbootstrap)
{
  genetrees = sim.coal.mpest(nulltree,ngenetree=ngenetree)
  write(genetrees,"testboot")
  tree1_loglike[i] = run.mpest(path_mpest= "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", 
                               genetreefile="testboot", species=speciesV, sptree=sp1$tree, ntree=ngenetree)$loglike
  tree2_loglike[i] = run.mpest(path_mpest= "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest",
                               genetreefile="testboot", species=speciesV, sptree=sp2$tree, ntree=ngenetree)$loglike
}

z = list(teststat=teststat, bootstrap = as.vector, nulltree=nulltree)

if(tree1_mpest$loglike > tree2_mpest$loglike){
  z$bootstrap = 2*(tree1_loglike - tree2_loglike)
}else{
  z$bootstrap = 2*(tree2_loglike - tree1_loglike)
}

pdf("test1.pdf")
d=density(z$bootstrap)
plot(d,main=NA, xlim=c(min(z$bootstrap),max(z$bootstrap,teststat)),xlab="test statistics", ylab="Density")
abline(v=teststat,lty=3)
dev.off()
z

#How many observations are > t-stat out of total
totalObs<-length(z$bootstrap)
greater<-length(z$bootstrap[z$bootstrap>z$teststat])
pvalue<-greater/totalObs
#there has to be a better way than this
sink("test1.txt")
totalObs
greater
pvalue
z
sink()

###Compare trees 1 & 3####
if(tree1_mpest$loglike > tree3_mpest$loglike){
  teststat = 2*(tree1_mpest$loglike - tree3_mpest$loglike)
  nulltree = tree3_mpest$tree
}else{
  teststat = 2*(tree3_mpest$loglike - tree1_mpest$loglike)
  nulltree = tree1_mpest$tree
}


tree1_loglike=tree3_loglike=1:nbootstrap

for(i in 1:nbootstrap)
{
  genetrees = sim.coal.mpest(nulltree,ngenetree=ngenetree)
  write(genetrees,"testboot")
  tree1_loglike[i] = run.mpest(path_mpest= "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", 
                               genetreefile="testboot", species=speciesV, sptree=sp1$tree, ntree=ngenetree)$loglike
  tree3_loglike[i] = run.mpest(path_mpest= "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest",
                               genetreefile="testboot", species=speciesV, sptree=sp3$tree, ntree=ngenetree)$loglike
}

z = list(teststat=teststat, bootstrap = as.vector, nulltree=nulltree)

if(tree1_mpest$loglike > tree3_mpest$loglike){
  z$bootstrap = 2*(tree1_loglike - tree3_loglike)
}else{
  z$bootstrap = 2*(tree3_loglike - tree1_loglike)
}

pdf("test2.pdf")
d=density(z$bootstrap)
plot(d,main=NA, xlim=c(min(z$bootstrap),max(z$bootstrap,teststat)),xlab="test statistics", ylab="Density")
abline(v=teststat,lty=3)
dev.off()

z

#How many observations are > t-stat out of total
totalObs<-length(z$bootstrap)
greater<-length(z$bootstrap[z$bootstrap>z$teststat])
pvalue<-greater/totalObs
#there has to be a better way than this
sink("test2.txt")
totalObs
greater
pvalue
z
sink()

###Compare trees 2 & 3####
if(tree2_mpest$loglike > tree3_mpest$loglike){
  teststat = 2*(tree2_mpest$loglike - tree3_mpest$loglike)
  nulltree = tree3_mpest$tree
}else{
  teststat = 2*(tree3_mpest$loglike - tree2_mpest$loglike)
  nulltree = tree2_mpest$tree
}


tree2_loglike=tree3_loglike=1:nbootstrap

for(i in 1:nbootstrap)
{
  genetrees = sim.coal.mpest(nulltree,ngenetree=ngenetree)
  write(genetrees,"testboot")
  tree2_loglike[i] = run.mpest(path_mpest= "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest", 
                               genetreefile="testboot", species=speciesV, sptree=sp2$tree, ntree=ngenetree)$loglike
  tree3_loglike[i] = run.mpest(path_mpest= "~/Dropbox/salmoUCEs/mp-est/mpest_2-2.0/mac/mpest",
                               genetreefile="testboot", species=speciesV, sptree=sp3$tree, ntree=ngenetree)$loglike
}

z = list(teststat=teststat, bootstrap = as.vector, nulltree=nulltree)

if(tree2_mpest$loglike > tree3_mpest$loglike){
  z$bootstrap = 2*(tree2_loglike - tree3_loglike)
}else{
  z$bootstrap = 2*(tree3_loglike - tree2_loglike)
}

pdf("test3.pdf")
d=density(z$bootstrap)
plot(d,main=NA, xlim=c(min(z$bootstrap),max(z$bootstrap,teststat)),xlab="test statistics", ylab="Density")
abline(v=teststat,lty=3)
dev.off()

z

#How many observations are > t-stat out of total
totalObs<-length(z$bootstrap)
greater<-length(z$bootstrap[z$bootstrap>z$teststat])
pvalue<-greater/totalObs
#there has to be a better way than this
sink("test3.txt")
totalObs
greater
pvalue
z
sink()
